# MM tokenizer plugin

MM tokenizer class module. Once enabled, it allows you to use the MM tokenizer as ImageSpec in your Flyte tasks.

To install the plugin, run the following command:

```bash
pip install mm-tokenizer
```
